% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/blip.r
\name{blip}
\alias{blip}
\title{Draws one-dimensional distribution plots.
Blip can be used to construct standard or customized distribution plots.}
\usage{
blip(..., std.plot = "", graph.region = c(0.25, 0.75), graph.type = "c",
  graph.width = "f", graph.uniform = T, text.cex = 1, nclass = 5,
  box.p = c(0.25, 0.5, 0.75), box.p.bar = rep(T, length(box.p)),
  box.label.on = T, box.label.cex = par("cex"), box.label.above = 0.05,
  box.density = 0, box.angle = 45, box.col = c(par("col")),
  line.extend.p = NA, line.percentile = NA, line.percentile.length = 6,
  line.percentile.col = par("col"), line.percentile.width = par("lwd"),
  line.extend.sd = NA, line.extend.se = NA, mean.pch = NA,
  mean.cex = par("cex"), mean.col = par("col"),
  line.extend.col = par("col"), line.extend.width = par("lwd"),
  point.pattern = "on-line", point.type = "p", point.cex = 0.7,
  point.pch = par("pch"), point.col = par("col"), xlim = NA, axes = T,
  xaxt = "s", xlab = "", ylab = "", breaks = NA, seed = 500,
  orientation = "horizontal", vertical.xstart = "left", violin.bp = F,
  violin.sp = F, violin.bp.region = c(0.45, 0.55))
}
\arguments{
\item{...}{Vectors or lists containing numeric components(e.g. the output of split) to be plotted.
Missing values(NAs) are allowed.}

\item{std.plot}{This option overrides all other related graphical parameters.
std.plot="boxplot" draws conventional boxplots;
std.plot="histogram" produces histogram;
std.plot="polygon" plots frequency polygon.}

\item{graph.region}{A numerical vector with 2 elements which specifies the lower and upper graphical region between 0 and 1.}

\item{graph.type}{A character value indicating the reference line.
"c" for centered and "b" for baseline.}

\item{graph.width}{A character value indicating the type of width of the box.
"f" for fixed and "v" for variable.}

\item{graph.uniform}{A logical value(T/F) to indicate the choice of uniform/non-uniform height on y-axis across groups.}

\item{text.cex}{A number to control the size of the text and symbols relative to the default.}

\item{nclass}{The smoothing parameter which corresponds to how many classes the total number of observations will be divided.}

\item{box.p}{A numeric vector of percentiles ranging from 0 to 1.
Missing values are not allowed in the vector except box.p=NA.
Numeric value 0 can be used as a separator for separatingboxes.
Each box must contain at least two percentiles.}

\item{box.p.bar}{A vector of logical value indicating whether to draw the vertical bars on percentiles.}

\item{box.label.on}{A Logical value indicating whether to label the percentiles on the boxes.}

\item{box.label.cex}{A numeric value to control the size of the labels.}

\item{box.label.above}{A numeric value indicating the distance of the labels above the box.}

\item{box.density}{A numeric value to indicate the density of the box shading lines.}

\item{box.angle}{A numeric value to indicate the angle of the box shading lines.}

\item{box.col}{A vector to indicate the color(s) of the box shading lines.}

\item{line.extend.p}{A numeric vector of percentiles ranging from 0 to 1, indicating segments of lines to be drawn outside the boxes.}

\item{line.percentile}{A numeric vector of percentiles ranging from 0 to 1, indicating segments of lines to be drawn outside the boxes.}

\item{line.percentile.length}{A numeric value indicating the length of the line.}

\item{line.percentile.col}{A numeric value indicating the color of the line.}

\item{line.percentile.width}{A numeric value indicating the width of the line.}

\item{line.extend.sd}{A numeric value indicating the length of lines to be drawn from the mean in standard deviation.}

\item{line.extend.se}{A numeric value indicating the length of lines to be drawn from the mean in standard error.}

\item{mean.pch}{A numeric value to specify the symbol for marking the location of the mean.
mean.pch=4 corresponds to "x".}

\item{mean.cex}{A numeric value to specify the size of mean symbol.}

\item{mean.col}{A numeric value to specify the color of mean symbol.}

\item{line.extend.col}{A numeric value to indicate the color of the line.}

\item{line.extend.width}{A numeric value to indicate the thickness of the line.}

\item{point.pattern}{When point.pattern="on-line", the points outside the boxes will be displayed on the reference line.
When point.pattern="stacking", the points outside the boxes will be separated by a fixed distance if there are more than one points with the same value.
When point.pattern="evenly-spaced", the points outside the boxes will be evenly spreaded out if there are more than one points with the same value.
When point.pattern="jittered", the points outside the boxes will be displayed randomly within the graph width.
When point.pattern="max-range", the points outside the boxes will be drawn at the maximum height of that point.
When point.pattern="vertical-bar", a vertical bar instead of a point will be drawn at the location of each observation.}

\item{point.type}{A character value to indicate whether a point("p"),a line("l"), both("b"), or none("n") will be drawn.}

\item{point.cex}{A numeric value to specify the size of points}

\item{point.pch}{A numeric or character value to specify the shape of points.}

\item{point.col}{A numeric value to specify the color of the points.}

\item{xlim}{A numeric vector consists of 2 elements which indicates the range of x-axis.}

\item{axes}{A logical value to indicate whether or not to plot axes.}

\item{xaxt}{"s"=standard x-axis plotting,"n"=null x-axis plotting.}

\item{xlab}{Labels on x-axis.}

\item{ylab}{Labels on y-axis.}

\item{breaks}{A numeric vector indicating break points for histogram and polygon.}

\item{seed}{An integer. This is a seed for the random number generator which is used in point.pattern="jittered".}

\item{orientation}{Orientation of the graph. Options are "horizontal" and "vertical".}

\item{vertical.xstart}{The side the x-values start from when the orientation of the graph is vertical.
"left" displays x-values in ascending order; "right" displays x-values in descending order.}

\item{violin.bp}{Indicates whether to draw a boxplot over the violin plot. Ignored if std.plot != "violin"}

\item{violin.sp}{Indicates whether to draw a scatterplot over the violin plot. Ignored if std.plot != "violin"}

\item{violin.bp.region}{Indicates upper and lower limits of a violin boxplot.}
}
\description{
Draws one-dimensional distribution plots.
Blip can be used to construct standard or customized distribution plots.
}
\examples{
x <- rnorm(100)
y <- c(rep(1, 50), rep(2, 50))
blip(x, std.plot = "boxplot")
blip(x, graph.type = "b", graph.width = "v", box.p = (0:10) / 10)
}

