library(testthat)

test_that("check.common.input terminates for invalid std.plot", {
  expect_error(check.common.input(c(1, 2, 3), "invalid", c(.25, .75), 3, c(0, 5), c(0, 5)))
  expect_error(check.common.input(c(1, 2, 3), "polygn", c(.25, .75), 3, c(0, 5), c(0, 5)))
  expect_error(check.common.input(c(1, 2, 3), "blip", c(.25, .75), 3, c(0, 5), c(0, 5)))
})

test_that("check.common.input terminates for invalid graph.region", {
  expect_error(check.common.input(c(1, 2, 3), "", c(.75, .25), 3, c(0, 5), c(0, 5)))
  expect_error(check.common.input(c(1, 2, 3), "", c(.5, .5), 3, c(0, 5), c(0, 5)))
  expect_error(check.common.input(c(1, 2, 3), "", c(.5), 3, c(0, 5), c(0, 5)))
})

test_that("check.common.input terminates for invalid nclass", {
  expect_error(check.common.input(c(1, 2, 3), "", c(.25, .75), F, c(0, 5), c(0, 5)))
  expect_error(check.common.input(c(1, 2, 3), "", c(.25, .75), "num", c(0, 5), c(0, 5)))
})

test_that("check.common.input terminates for invalid xlim", {
  expect_error(check.common.input(c(1, 2, 3), "", c(.25, .75), 1, c(4, 2), c(0, 5)))
  expect_error(check.common.input(c(1, 2, 3), "", c(.25, .75), 1, c(2, 2), c(0, 5)))
  expect_error(check.common.input(c(1, 2, 3), "", c(.25, .75), 1, c(2), c(0, 5)))
  expect_silent(check.common.input(c(1, 2, 3), "", c(.25, .75), 1, c(NA, NA), c(0, 5)))
})

test_that("check.common.input terminates for invalid breaks", {
  expect_error(check.common.input(c(1, 2, 3), "histogram", c(.25, .75), 1, c(0, 5), c(2, 5)))
  expect_error(check.common.input(c(1, 2, 3), "histogram", c(.25, .75), 1, c(0, 5), c(0, 2)))
  expect_error(check.common.input(c(1, 2, 3), "histogram", c(.25, .75), 1, c(0, 5), c(4, 1)))
  expect_error(check.common.input(c(1, 2, 3), "histogram", c(.25, .75), 1, c(0, 5), c(1, 2, 3, 4, 2)))
})

test_that("check.common.input returns correct x.min and x.max", {
  test1 <- check.common.input(c(1, 2, 3), "boxplot", c(.25, .75), 3, c(0, 5), c(-2, 7))
  expect_equal(test1$x.min, 1)
  expect_equal(test1$x.max, 3)

  test1 <- check.common.input(c(1, 2, 3), "histogram", c(.25, .75), 3, c(0, 5), c(0, 5))
  expect_equal(test1$x.min, 0)
  expect_equal(test1$x.max, 5)

  test1 <- check.common.input(c(1, 2, 3), "polygon", c(.25, .75), 3, c(0, 5), c(-2, 7))
  expect_equal(test1$x.min, -2)
  expect_equal(test1$x.max, 7)

  test1 <- check.common.input(c(0, 1, 2, 3, 4, 5), "", c(.25, .75), 3, c(0, 5), c(-2, 7))
  expect_equal(test1$x.min, 0)
  expect_equal(test1$x.max, 5)
})
