library(testthat)

test_that("check.input.blip terminates for invalid line.extend.sd", {
  expect_error(check.input.blip(list(c(1, 2, 3)), 1, NA, NA, "c", "f", "stacking", .1, c(.1, .2), .1))
  expect_error(check.input.blip(list(c(1, 2, 3)), 1, NA, NA, "c", "f", "stacking", .1, c(T, T), .1))
})

test_that("check.input.blip terminates for invalid line.extend.se", {
  expect_error(check.input.blip(list(c(1, 2, 3)), 1, NA, NA, "c", "f", "stacking", .1, .1, c(.1, .2)))
  expect_error(check.input.blip(list(c(1, 2, 3)), 1, NA, NA, "c", "f", "stacking", .1, .1, c(T, T)))
})

test_that("check.input.blip terminates for invalid graph.type", {
  expect_error(check.input.blip(list(c(1, 2, 3)), 1, NA, rep(T, length(box.p)), "o", "f", "stacking", .1, .1, .2))
  expect_error(check.input.blip(list(c(1, 2, 3)), 1, NA, rep(T, length(box.p)), "k", "f", "stacking", .1, .1, .2))
  expect_silent(check.input.blip(list(c(1, 2, 3)), 1, c(.25, .5, .75),
                                 rep(T, length(c(.25, .5, .75))), "c", "f", "stacking", NA, .1, .2))
  expect_silent(check.input.blip(list(c(1, 2, 3)), 1, c(.25, .5, .75),
                                 rep(T, length(c(.25, .5, .75))), "b", "f", "stacking", NA, .1, .2))
})

test_that("check.input.blip terminates for invalid graph.width", {
  expect_error(check.input.blip(list(c(1, 2, 3)), 1, NA, NA, "c", "o", "stacking", .1, .1, .2))
  expect_error(check.input.blip(list(c(1, 2, 3)), 1, NA, NA, "c", "k", "stacking", .1, .1, .2))
  expect_silent(check.input.blip(list(c(1, 2, 3)), 1, c(.25, .5, .75),
                                 rep(T, length(c(.25, .5, .75))), "c", "f", "stacking", NA, .1, .2))
  expect_silent(check.input.blip(list(c(1, 2, 3)), 1, c(.25, .5, .75),
                                 rep(T, length(c(.25, .5, .75))), "b", "v", "stacking", NA, .1, .2))
})

test_that("check.input.blip terminates for invalid point.pattern", {
  expect_error(check.input.blip(list(c(1, 2, 3)), 1, NA, NA, "c", "o", "bad", .1, .1, .2))
  expect_error(check.input.blip(list(c(1, 2, 3)), 1, NA, NA, "c", "k", "also bad", .1, .1, .2))
  expect_silent(check.input.blip(list(c(1, 2, 3)), 1, c(.25, .5, .75),
                                 rep(T, length(c(.25, .5, .75))), "c", "f", "on-line", NA, .1, .2))
  expect_silent(check.input.blip(list(c(1, 2, 3)), 1, c(.25, .5, .75),
                                 rep(T, length(c(.25, .5, .75))), "b", "v", "stacking", NA, .1, .2))
  expect_silent(check.input.blip(list(c(1, 2, 3)), 1, c(.25, .5, .75),
                                 rep(T, length(c(.25, .5, .75))), "c", "f", "evenly-spaced", NA, .1, .2))
  expect_silent(check.input.blip(list(c(1, 2, 3)), 1, c(.25, .5, .75),
                                 rep(T, length(c(.25, .5, .75))), "b", "v", "jittered", NA, .1, .2))
  expect_silent(check.input.blip(list(c(1, 2, 3)), 1, c(.25, .5, .75),
                                 rep(T, length(c(.25, .5, .75))), "c", "f", "max-range", NA, .1, .2))
  expect_silent(check.input.blip(list(c(1, 2, 3)), 1, c(.25, .5, .75),
                                 rep(T, length(c(.25, .5, .75))), "b", "v", "vertical-bar", NA, .1, .2))
})

test_that("check.input.blip terminates for invalid box.p", {
  expect_error(check.input.blip(list(c(1, 2, 3)), 1, c(.25, NA, .75),
                                 rep(T, length(c(.25, .5, .75))), "c", "f", "stacking", NA, .1, .2))
  expect_error(check.input.blip(list(c(1, 2, 3)), 1, c(.65, .5, .75),
                                 rep(T, length(c(.25, .5, .75))), "b", "v", "stacking", NA, .1, .2))
  expect_error(check.input.blip(list(c(1, 2, 3)), 1, c(.25),
                                 rep(T, length(c(.25, .5, .75))), "c", "f", "stacking", NA, .1, .2))
  expect_error(check.input.blip(list(c(1, 2, 3)), 1, c(.25, .25, .5, .75),
                                 rep(T, length(c(.25, .5, .75))), "b", "v", "stacking", NA, .1, .2))
  expect_error(check.input.blip(list(c(1, 2, 3)), 1, c(.25, .5, 1.01),
                                rep(T, length(c(.25, .5, .75))), "c", "f", "stacking", NA, .1, .2))
  expect_error(check.input.blip(list(c(1, 2, 3)), 1, c(-1, .5, .75),
                                rep(T, length(c(.25, .5, .75))), "c", "f", "stacking", NA, .1, .2))
  expect_error(check.input.blip(list(c(1, 2, 3)), 1, c(0, 0, 0),
                                rep(T, length(c(.25, .5, .75))), "c", "f", "stacking", NA, .1, .2))
})

test_that("check.input.blip terminates for invalid box.p.bar", {
  expect_error(check.input.blip(list(c(1, 2, 3)), 1, c(.25, .5, .75),
                                c(T, T, 0.2), "c", "f", "stacking", NA, .1, .2))
  expect_error(check.input.blip(list(c(1, 2, 3)), 1, c(.25, .5, .75),
                                c(T, T, T, T), "b", "v", "stacking", NA, .1, .2))
})

test_that("check.input.blip terminates for invalid line.extend.p", {
  expect_error(check.input.blip(list(c(1, 2, 3)), 1, c(.25, .5, .75),
                                c(T, T, T), "c", "f", "stacking", .1, .1, .2))
  expect_error(check.input.blip(list(c(1, 2, 3)), 1, c(.25, .5, .75),
                                c(T, T, T), "b", "v", "stacking", c(.1, .3, .2), .1, .2))
  expect_error(check.input.blip(list(c(1, 2, 3)), 1, c(.25, .5, .75),
                                c(T, T, T), "b", "v", "stacking", c(.1, .1, .2), .1, .2))
})
