library(testthat)

test_that("define.var returns x sorted", {
  x1 <- list(c(5, 1, 8, 0, -2, 7))
  var1 <- define.var(x1, c(.25, .75))
  expect_equal(var1$x, list(c(-2, 0, 1, 5, 7, 8)))

  x2 <- list(c(5, 1, 8, 0, -2, 7), c(3, 1, 8, 2))
  var2 <- define.var(x2, c(.25, .75))
  expect_equal(var2$x, list(c(-2, 0, 1, 5, 7, 8), c(1, 2, 3, 8)))
})

test_that("define.var returns correct nvectors", {
  x1 <- list(c(5, 1, 8, 0, -2, 7))
  var1 <- define.var(x1, c(.25, .75))
  expect_equal(var1$nvectors, 1)

  x2 <- list(c(5, 1, 8, 0, -2, 7), c(3, 1, 8, 2))
  var2 <- define.var(x2, c(.25, .75))
  expect_equal(var2$nvectors, 2)

  x3 <- list(c(5, 1, 8, 0, -2, 7), c(3, 1, 8, 2), 3)
  var3 <- define.var(x3, c(.25, .75))
  expect_equal(var3$nvectors, 3)
})

test_that("define.var returns correct n", {
  x1 <- list(c(5, 1, 8, 0, -2, 7))
  var1 <- define.var(x1, c(.25, .75))
  expect_equal(var1$n, c(6))

  x2 <- list(c(5, 1, 8, 0, -2, 7), c(3, 1, 8, 2))
  var2 <- define.var(x2, c(.25, .75))
  expect_equal(var2$n, c(6, 4))

  x3 <- list(c(5, 1, 8, 0, -2, 7), c(3, 1, 8, 2), 3)
  var3 <- define.var(x3, c(.25, .75))
  expect_equal(var3$n, c(6, 4, 1))
})

test_that("define.var returns correct low", {
  x1 <- list(c(5, 1, 8, 0, -2, 7))
  var1 <- define.var(x1, c(.1, .75))
  expect_equal(var1$low, c(.1))

  x2 <- list(c(5, 1, 8, 0, -2, 7), c(3, 1, 8, 2))
  var2 <- define.var(x2, c(.3, .6))
  expect_equal(var2$low, c(.15, .65))

  x3 <- list(c(5, 1, 8, 0, -2, 7), c(3, 1, 8, 2), 3, c(1, 5))
  var3 <- define.var(x3, c(.2, .8))
  expect_equal(var3$low, c(.05, .30, .55, .80))
})

test_that("define.var returns correct up", {
  x1 <- list(c(5, 1, 8, 0, -2, 7))
  var1 <- define.var(x1, c(.1, .75))
  expect_equal(var1$up, c(.75))

  x2 <- list(c(5, 1, 8, 0, -2, 7), c(3, 1, 8, 2))
  var2 <- define.var(x2, c(.3, .6))
  expect_equal(var2$up, c(.3, .8))

  x3 <- list(c(5, 1, 8, 0, -2, 7), c(3, 1, 8, 2), 3, c(1, 5))
  var3 <- define.var(x3, c(.2, .8))
  expect_equal(var3$up, c(.20, .45, .70, .95))
})

test_that("define.var returns correct boxwidth", {
  x1 <- list(c(5, 1, 8, 0, -2, 7))
  var1 <- define.var(x1, c(.1, .75))
  expect_equal(var1$boxwidth, c(.65))

  x2 <- list(c(5, 1, 8, 0, -2, 7), c(3, 1, 8, 2))
  var2 <- define.var(x2, c(.3, .6))
  expect_equal(var2$boxwidth, c(.15, .15))

  x3 <- list(c(5, 1, 8, 0, -2, 7), c(3, 1, 8, 2), 3, c(1, 5))
  var3 <- define.var(x3, c(.2, .8))
  expect_equal(var3$boxwidth, c(.15, .15, .15, .15))
})

test_that("define.var returns correct boxcenter", {
  x1 <- list(c(5, 1, 8, 0, -2, 7))
  var1 <- define.var(x1, c(.1, .75))
  expect_equal(var1$boxcenter, c(.425))

  x2 <- list(c(5, 1, 8, 0, -2, 7), c(3, 1, 8, 2))
  var2 <- define.var(x2, c(.3, .6))
  expect_equal(var2$boxcenter, c(.225, .725))

  x3 <- list(c(5, 1, 8, 0, -2, 7), c(3, 1, 8, 2), 3, c(1, 5))
  var3 <- define.var(x3, c(.2, .8))
  expect_equal(var3$boxcenter, c(.125, .375, .625, .875))
})

test_that("define.var returns correct lower.edge", {
  x1 <- list(c(5, 1, 8, 0, -2, 7))
  var1 <- define.var(x1, c(.1, .75))
  expect_equal(var1$lower.edge, .1)

  x2 <- list(c(5, 1, 8, 0, -2, 7), c(3, 1, 8, 2))
  var2 <- define.var(x2, c(.3, .6))
  expect_equal(var2$lower.edge, .3)

  x3 <- list(c(5, 1, 8, 0, -2, 7), c(3, 1, 8, 2), 3, c(1, 5))
  var3 <- define.var(x3, c(.2, .8))
  expect_equal(var3$lower.edge, .2)
})

test_that("define.var returns correct upper.edge", {
  x1 <- list(c(5, 1, 8, 0, -2, 7))
  var1 <- define.var(x1, c(.1, .75))
  expect_equal(var1$upper.edge, .75)

  x2 <- list(c(5, 1, 8, 0, -2, 7), c(3, 1, 8, 2))
  var2 <- define.var(x2, c(.3, .6))
  expect_equal(var2$upper.edge, .6)

  x3 <- list(c(5, 1, 8, 0, -2, 7), c(3, 1, 8, 2), 3, c(1, 5))
  var3 <- define.var(x3, c(.2, .8))
  expect_equal(var3$upper.edge, .8)
})
